@@ -8,8 +8,9 @@ import { errorModal } from '@console/internal/components/modals';
 import { PipelineModel, PipelineRunModel } from '../models';
 import startPipelineModal from '../components/pipelines/pipeline-form/StartPipelineModal';
 import { getRandomChars } from '../components/pipelines/pipeline-resource/pipelineResource-utils';
-import { Pipeline, PipelineRun } from './pipeline-augment';
+import { Pipeline, PipelineParam, PipelineRun, PipelineRunParam } from './pipeline-augment';
 import { pipelineRunFilterReducer } from './pipeline-filter-reducer';
+import { getPipelineRunParams } from './pipeline-utils';
 
 interface Action {
   label: string | Record<string, any>;
@@ -30,6 +31,32 @@ const redirectToResourceList = (resource: string) => {
 export const handlePipelineRunSubmit = (pipelineRun: PipelineRun) => {
   redirectToResourceList(`pipelineruns/${pipelineRun.metadata.name}`);
 };
+
+/**
+ * Migrates a PipelineRun from one version to another to support auto-upgrades with old (and invalid) PipelineRuns.
+ *
+ * Note: Each check within this method should be driven by the apiVersion number if the API is properly up-versioned
+ * for these breaking changes. (should be done moving from 0.10.x forward)
+ */
+export const migratePipelineRun = (pipelineRun: PipelineRun): PipelineRun => {
+  let newPipelineRun = pipelineRun;
+
+  const serviceAccountPath = 'spec.serviceAccount';
+  if (_.has(newPipelineRun, serviceAccountPath)) {
+    // .spec.serviceAccount was removed for .spec.serviceAccountName in 0.9.x
+    // Note: apiVersion was not updated for this change and thus we cannot gate this change behind a version number
+    const serviceAccountName = _.get(newPipelineRun, serviceAccountPath);
+    newPipelineRun = _.omit(newPipelineRun, [serviceAccountPath]);
+    newPipelineRun = _.merge(newPipelineRun, {
+      spec: {
+        serviceAccountName,
+      },
+    });
+  }
+
+  return newPipelineRun;
+};
+
 export const getPipelineRunData = (pipeline: Pipeline, latestRun?: PipelineRun): PipelineRun => {
   if (!pipeline || !pipeline.metadata || !pipeline.metadata.name || !pipeline.metadata.namespace) {
     // eslint-disable-next-line no-console
@@ -45,8 +72,11 @@ export const getPipelineRunData = (pipeline: Pipeline, latestRun?: PipelineRun):
     resourceRef: resource.resourceRef,
   }));
 
-  return {
-    apiVersion: `${PipelineRunModel.apiGroup}/${PipelineRunModel.apiVersion}`,
+  const pipelineRunParams: PipelineRunParam[] = _.get(latestRun, 'spec.params');
+  const pipelineParams: PipelineParam[] = _.get(pipeline, 'spec.params');
+
+  const newPipelineRun: PipelineRun = {
+    apiVersion: pipeline ? pipeline.apiVersion : latestRun.apiVersion,
     kind: PipelineRunModel.kind,
     metadata: {
       name: `${pipeline.metadata.name}-${getRandomChars(6)}`,
@@ -59,19 +89,16 @@ export const getPipelineRunData = (pipeline: Pipeline, latestRun?: PipelineRun):
             },
     },
     spec: {
+      ..._.get(latestRun, 'spec', {}),
       pipelineRef: {
         name: pipeline.metadata.name,
       },
       resources,
-      params:
-        latestRun && latestRun.spec && latestRun.spec.params
-          ? latestRun.spec.params
-          : pipeline.spec && pipeline.spec.params
-          ? pipeline.spec.params
-          : null,
-      serviceAccount: latestRun && _.get(latestRun, ['spec', 'serviceAccount']),
+      params: pipelineRunParams || getPipelineRunParams(pipelineParams),
     },
   };
+
+  return migratePipelineRun(newPipelineRun);
 };
 
 export const triggerPipeline = (
