@@ -117,36 +117,6 @@ export const createKnativeService = (
   return k8sCreate(ServiceModel, knativeDeployResource);
 };
 
-export const knativeServingResources = (namespace: string): FirehoseResource[] => {
-  const knativeResource = [
-    {
-      isList: true,
-      kind: referenceForModel(RevisionModel),
-      namespace,
-      prop: 'revisions',
-    },
-    {
-      isList: true,
-      kind: referenceForModel(ConfigurationModel),
-      namespace,
-      prop: 'configurations',
-    },
-    {
-      isList: true,
-      kind: referenceForModel(RouteModel),
-      namespace,
-      prop: 'ksroutes',
-    },
-    {
-      isList: true,
-      kind: referenceForModel(ServiceModel),
-      namespace,
-      prop: 'ksservices',
-    },
-  ];
-  return knativeResource;
-};
-
 export const knativeServingResourcesRevision = (namespace: string): FirehoseResource[] => {
   const knativeResource = [
     {
@@ -154,6 +124,7 @@ export const knativeServingResourcesRevision = (namespace: string): FirehoseReso
       kind: referenceForModel(RevisionModel),
       namespace,
       prop: 'revisions',
+      optional: true,
     },
   ];
   return knativeResource;
@@ -166,6 +137,7 @@ export const knativeServingResourcesConfigurations = (namespace: string): Fireho
       kind: referenceForModel(ConfigurationModel),
       namespace,
       prop: 'configurations',
+      optional: true,
     },
   ];
   return knativeResource;
@@ -178,6 +150,23 @@ export const knativeServingResourcesRoutes = (namespace: string): FirehoseResour
       kind: referenceForModel(RouteModel),
       namespace,
       prop: 'ksroutes',
+      optional: true,
+    },
+  ];
+  return knativeResource;
+};
+
+export const knativeServingResources = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    ...knativeServingResourcesRevision(namespace),
+    ...knativeServingResourcesConfigurations(namespace),
+    ...knativeServingResourcesRoutes(namespace),
+    {
+      isList: true,
+      kind: referenceForModel(ServiceModel),
+      namespace,
+      prop: 'ksservices',
+      optional: true,
     },
   ];
   return knativeResource;
