@@ -2,14 +2,15 @@ import * as _ from 'lodash-es';
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { connect } from 'react-redux';
-import { Link } from 'react-router-dom';
-
+import * as classNames from 'classnames';
+import { ActionGroup, Button } from '@patternfly/react-core';
+import { sortable } from '@patternfly/react-table';
+import { ClusterRoleBindingModel } from '../../models';
 import { getQN, k8sCreate, k8sPatch, referenceFor } from '../../module/k8s';
-import { getActiveNamespace, formatNamespacedRouteForResource, UIActions } from '../../ui/ui-actions';
-import { ColHead, List, ListHeader, MultiListPage, ResourceRow } from '../factory';
+import * as UIActions from '../../actions/ui';
+import { MultiListPage, Table, TableRow, TableData } from '../factory';
 import { RadioGroup } from '../radio';
 import { confirmModal } from '../modals';
-import { SafetyFirst } from '../safety-first';
 import {
   ButtonBar,
   Kebab,
@@ -25,9 +26,11 @@ import {
   history,
   kindObj,
   resourceObjPath,
+  useAccessReview,
 } from '../utils';
 import { isSystemRole } from './index';
-import { connectToFlags, FLAGS, flagPending } from '../../features';
+import { connectToFlags, flagPending } from '../../reducers/features';
+import { FLAGS } from '../../const';
 
 const bindingKind = binding => binding.metadata.namespace ? 'RoleBinding' : 'ClusterRoleBinding';
 
@@ -60,27 +63,44 @@ const menuActions = ({subjectIndex, subjects}, startImpersonate) => {
 
   const actions = [
     (kind, obj) => ({
-      label: `Duplicate ${kind.label}...`,
+      label: `Duplicate ${kind.label}`,
       href: `${resourceObjPath(obj, kind.kind)}/copy?subjectIndex=${subjectIndex}`,
+      // Only perform access checks when duplicating cluster role bindings.
+      // It's not practical to check namespace role bindings since we don't know what namespace the user will pick in the form.
+      accessReview: _.get(obj, 'metadata.namespace') ? null : { group: kind.apiGroup, resource: kind.plural, verb: 'create' },
     }),
     (kind, obj) => ({
-      label: `Edit ${kind.label} Subject...`,
+      label: `Edit ${kind.label} Subject`,
       href: `${resourceObjPath(obj, kind.kind)}/edit?subjectIndex=${subjectIndex}`,
+      accessReview: {
+        group: kind.apiGroup,
+        resource: kind.plural,
+        name: obj.metadata.name,
+        namespace: obj.metadata.namespace,
+        verb: 'update',
+      },
     }),
     subjects.length === 1 ? Kebab.factory.Delete : (kind, binding) => ({
-      label: `Delete ${kind.label} Subject...`,
+      label: `Delete ${kind.label} Subject`,
       callback: () => confirmModal({
         title: `Delete ${kind.label} Subject`,
         message: `Are you sure you want to delete subject ${subject.name} of type ${subject.kind}?`,
         btnText: 'Delete Subject',
         executeFn: () => k8sPatch(kind, binding, [{op: 'remove', path: `/subjects/${subjectIndex}`}]),
       }),
+      accessReview: {
+        group: kind.apiGroup,
+        resource: kind.plural,
+        name: binding.metadata.name,
+        namespace: binding.metadata.namespace,
+        verb: 'patch',
+      },
     }),
   ];
 
   if (subject.kind === 'User' || subject.kind === 'Group') {
     actions.unshift(() => ({
-      label: `Impersonate ${subject.kind} "${subject.name}"...`,
+      label: `Impersonate ${subject.kind} "${subject.name}"`,
       callback: () => startImpersonate(subject.kind, subject.name),
     }));
   }
@@ -88,13 +108,43 @@ const menuActions = ({subjectIndex, subjects}, startImpersonate) => {
   return actions;
 };
 
-const Header = props => <ListHeader>
-  <ColHead {...props} className="col-md-3 col-sm-4 col-xs-6" sortField="metadata.name">Name</ColHead>
-  <ColHead {...props} className="col-md-3 col-sm-4 hidden-xs" sortField="roleRef.name">Role Ref</ColHead>
-  <ColHead {...props} className="col-md-2 hidden-sm hidden-xs" sortField="subject.kind">Subject Kind</ColHead>
-  <ColHead {...props} className="col-md-2 hidden-sm hidden-xs" sortField="subject.name">Subject Name</ColHead>
-  <ColHead {...props} className="col-md-2 col-sm-4 col-xs-6" sortField="metadata.namespace">Namespace</ColHead>
-</ListHeader>;
+const tableColumnClasses = [
+  classNames('col-md-3', 'col-sm-4', 'col-xs-6'),
+  classNames('col-md-3', 'col-sm-4', 'hidden-xs'),
+  classNames('col-lg-2', 'col-md-3', 'hidden-sm', 'hidden-xs'),
+  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
+  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'col-xs-6'),
+  Kebab.columnClass,
+];
+
+const RoleBindingsTableHeader = () => {
+  return [
+    {
+      title: 'Name', sortField: 'metadata.name', transforms: [sortable],
+      props: { className: tableColumnClasses[0] },
+    },
+    {
+      title: 'Role Ref', sortField: 'roleRef.name', transforms: [sortable],
+      props: { className: tableColumnClasses[1] },
+    },
+    {
+      title: 'Subject Kind', sortField: 'subject.kind', transforms: [sortable],
+      props: { className: tableColumnClasses[2] },
+    },
+    {
+      title: 'Subject Name', sortField: 'subject.name', transforms: [sortable],
+      props: { className: tableColumnClasses[3] },
+    },
+    {
+      title: 'Namespace', sortField: 'metadata.namespace', transforms: [sortable],
+      props: { className: tableColumnClasses[4] },
+    },
+    {
+      title: '', props: { className: tableColumnClasses[5] },
+    },
+  ];
+};
+RoleBindingsTableHeader.displayName = 'RoleBindingsTableHeader';
 
 export const BindingName = ({binding}) => {
   <ResourceLink kind={bindingKind(binding)} name={binding.metadata.name} namespace={binding.metadata.namespace} className="co-resource-item__resource-name" />;
@@ -112,30 +162,35 @@ export const RoleLink = ({binding}) => {
   return <ResourceLink kind={kind} name={binding.roleRef.name} namespace={ns} />;
 };
 
-const Row = ({obj: binding}) => <ResourceRow obj={binding}>
-  <div className="col-md-3 col-sm-4 col-xs-6">
-    <ResourceLink kind={bindingKind(binding)} name={binding.metadata.name} namespace={binding.metadata.namespace} className="co-resource-item__resource-name" />
-  </div>
-  <div className="col-md-3 col-sm-4 hidden-xs co-break-word">
-    <RoleLink binding={binding} />
-  </div>
-  <div className="col-md-2 hidden-sm hidden-xs co-break-word">
-    {binding.subject.kind}
-  </div>
-  <div className="col-md-2 hidden-sm hidden-xs co-break-word">
-    {binding.subject.name}
-  </div>
-  <div className="col-md-2 col-sm-4 col-xs-6 co-break-word">
-    {binding.metadata.namespace ? <ResourceLink kind="Namespace" name={binding.metadata.namespace} /> : 'all'}
-  </div>
-  <div className="dropdown-kebab-pf">
-    <BindingKebab binding={binding} />
-  </div>
-</ResourceRow>;
+const RoleBindingsTableRow = ({obj: binding, index, key, style}) => {
+  return (
+    <TableRow id={binding.metadata.uid} index={index} trKey={key} style={style}>
+      <TableData className={tableColumnClasses[0]}>
+        <ResourceLink kind={bindingKind(binding)} name={binding.metadata.name} namespace={binding.metadata.namespace} className="co-resource-item__resource-name" />
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[1], 'co-break-word')}>
+        <RoleLink binding={binding} />
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[2], 'co-break-word')}>
+        {binding.subject.kind}
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[3], 'co-break-word')}>
+        {binding.subject.name}
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[4], 'co-break-word')}>
+        {binding.metadata.namespace ? <ResourceLink kind="Namespace" name={binding.metadata.namespace} /> : 'all'}
+      </TableData>
+      <TableData className={tableColumnClasses[5]}>
+        <BindingKebab binding={binding} />
+      </TableData>
+    </TableRow>
+  );
+};
+RoleBindingsTableRow.displayName = 'RoleBindingsTableRow';
 
 const EmptyMsg = () => <MsgBox title="No Role Bindings Found" detail="Roles grant access to types of objects in the cluster. Roles are applied to a group or user via a Role Binding." />;
 
-export const BindingsList = props => <List {...props} EmptyMsg={EmptyMsg} Header={Header} Row={Row} />;
+export const BindingsList = props => <Table {...props} aria-label="Role Bindings" EmptyMsg={EmptyMsg} Header={RoleBindingsTableHeader} Row={RoleBindingsTableRow} virtualize />;
 
 export const bindingType = binding => {
   if (!binding) {
@@ -157,7 +212,7 @@ export const RoleBindingsPage = ({namespace, showTitle=true, mock}) => <MultiLis
   createButtonText="Create Binding"
   createProps={{to: '/k8s/cluster/rolebindings/~new'}}
   mock={mock}
-  filterLabel="Role Bindings by role or subject"
+  filterLabel="by role or subject"
   flatten={flatten}
   label="Role Bindings"
   ListComponent={BindingsList}
@@ -236,7 +291,7 @@ const Section = ({label, children}) => <div>
 </div>;
 
 const BaseEditRoleBinding = connect(null, {setActiveNamespace: UIActions.setActiveNamespace})(
-  class BaseEditRoleBinding_ extends SafetyFirst {
+  class BaseEditRoleBinding_ extends React.Component {
     constructor(props) {
       super(props);
 
@@ -337,9 +392,9 @@ const BaseEditRoleBinding = connect(null, {setActiveNamespace: UIActions.setActi
           <h1 className="co-m-pane__heading">{title}</h1>
           <p className="co-m-pane__explanation">Associate a user/group to the selected role to define the type of access and resources that are allowed.</p>
 
-          <Section label="Binding Type">
-            {!_.get(fixed, 'kind') && <RadioGroup currentValue={kind} items={bindingKinds} onChange={this.setKind} />}
-          </Section>
+          {!_.get(fixed, 'kind') && <Section label="Binding Type">
+            <RadioGroup currentValue={kind} items={bindingKinds} onChange={this.setKind} />
+          </Section>}
 
           <div className="co-form-section__separator"></div>
 
@@ -348,7 +403,7 @@ const BaseEditRoleBinding = connect(null, {setActiveNamespace: UIActions.setActi
               <label htmlFor="role-binding-name" className="co-required">Name</label>
               {_.get(fixed, 'metadata.name')
                 ? <ResourceName kind={kind} name={metadata.name} />
-                : <input className="form-control" type="text" onChange={this.changeName} placeholder="Role binding name" value={metadata.name} required id="role-binding-name" />}
+                : <input className="pf-c-form-control" type="text" onChange={this.changeName} placeholder="Role binding name" value={metadata.name} required id="role-binding-name" />}
             </div>
             {kind === 'RoleBinding' && <div className="form-group">
               <label htmlFor="ns-dropdown" className="co-required">Namespace</label>
@@ -384,15 +439,27 @@ const BaseEditRoleBinding = connect(null, {setActiveNamespace: UIActions.setActi
             </div>}
             <div className="form-group">
               <label htmlFor="subject-name" className="co-required">Subject Name</label>
-              <input className="form-control" type="text" onChange={this.changeSubjectName} placeholder="Subject name" value={subject.name} required id="subject-name" />
+              <input className="pf-c-form-control" type="text" onChange={this.changeSubjectName} placeholder="Subject name" value={subject.name} required id="subject-name" />
             </div>
           </Section>
 
           <div className="co-form-section__separator"></div>
 
           <ButtonBar errorMessage={this.state.error} inProgress={this.state.inProgress}>
-            <button type="submit" className="btn btn-primary" id="save-changes">{saveButtonText || 'Create'}</button>
-            <Link to={formatNamespacedRouteForResource('rolebindings')} className="btn btn-default" id="cancel">Cancel</Link>
+            <ActionGroup className="pf-c-form">
+              <Button
+                type="submit"
+                id="save-changes"
+                variant="primary">
+                {saveButtonText || 'Create'}
+              </Button>
+              <Button
+                onClick={history.goBack}
+                id="cancel"
+                variant="secondary">
+                Cancel
+              </Button>
+            </ActionGroup>
           </ButtonBar>
         </form>
       </div>;
@@ -403,9 +470,14 @@ export const CreateRoleBinding = ({match: {params}, location}) => {
   const searchParams = new URLSearchParams(location.search);
   const roleKind = searchParams.get('rolekind');
   const roleName = searchParams.get('rolename');
-  const metadata = {namespace: getActiveNamespace()};
+  const metadata = {namespace: UIActions.getActiveNamespace()};
+  const clusterAllowed = useAccessReview({
+    group: ClusterRoleBindingModel.apiGroup,
+    resource: ClusterRoleBindingModel.plural,
+    verb: 'create',
+  });
   const fixed = {
-    kind: (params.ns || roleKind === 'Role') ? 'RoleBinding' : undefined,
+    kind: (params.ns || roleKind === 'Role' || !clusterAllowed) ? 'RoleBinding' : undefined,
     metadata: {namespace: params.ns},
     roleRef: {kind: roleKind, name: roleName},
   };
@@ -435,5 +507,5 @@ export const EditRoleBinding = ({match: {params}, kind}) => <Firehose resources=
 </Firehose>;
 
 export const CopyRoleBinding = ({match: {params}, kind}) => <Firehose resources={[{kind, name: params.name, namespace: params.ns, isList: false, prop: 'obj'}]}>
-  <BindingLoadingWrapper isCreate={true} subjectIndex={getSubjectIndex()} titleVerb="Duplicate" />
+  <BindingLoadingWrapper isCreate={true} fixedKeys={['kind']} subjectIndex={getSubjectIndex()} titleVerb="Duplicate" />
 </Firehose>;
