@@ -2,11 +2,23 @@ import * as React from 'react';
 import * as _ from 'lodash-es';
 import * as PropTypes from 'prop-types';
 import { connect } from 'react-redux';
-import { FieldLevelHelp, Alert } from 'patternfly-react';
+import { FieldLevelHelp } from 'patternfly-react';
+import { Alert, Button, ActionGroup, AlertActionCloseButton } from '@patternfly/react-core';
 import * as classNames from 'classnames';
 
 import { k8sPatch, k8sGet, referenceFor, referenceForOwnerRef } from '../module/k8s';
-import { PromiseComponent, NameValueEditorPair, EnvType, EnvFromPair, LoadingInline, LoadingBox, AsyncComponent, ContainerDropdown, ResourceLink } from './utils';
+import {
+  AsyncComponent,
+  checkAccess,
+  ContainerDropdown,
+  EnvFromPair,
+  EnvType,
+  LoadingBox,
+  LoadingInline,
+  NameValueEditorPair,
+  PromiseComponent,
+  ResourceLink,
+} from './utils';
 import { ConfigMapModel, SecretModel } from '../models';
 
 /**
@@ -83,17 +95,19 @@ const getContainersObjectForDropdown = (containerArray) => {
   }, {});
 };
 
-/** @type {(state: any, props: {obj?: object, rawEnvData?: any, readOnly: boolean, envPath: any, onChange?: (env: any) => void, addConfigMapSecret?: boolean, useLoadingInline?: boolean}) => {model: K8sKind}} */
-const stateToProps = ({k8s}, {obj}) => ({
-  model: k8s.getIn(['RESOURCES', 'models', referenceFor(obj)]) || k8s.getIn(['RESOURCES', 'models', obj.kind]),
-});
-
 class CurrentEnvVars {
-  constructor() {
+  constructor(data, isContainerArray, path) {
     this.currentEnvVars = {};
+    this.state = { allowed: true };
+    if (!_.isEmpty(data) && arguments.length > 1) {
+      this.setResultObject(data, isContainerArray, path);
+    } else {
+      this.setRawData(data);
+    }
   }
 
   setRawData(rawEnvData) {
+    this.rawEnvData = rawEnvData;
     this.isContainerArray = _.isArray(rawEnvData.containers);
     this.isCreate = _.isEmpty(rawEnvData);
     this.hasInitContainers = !_.isUndefined(rawEnvData.initContainers);
@@ -232,6 +246,13 @@ class CurrentEnvVars {
       });
   }
 }
+
+/** @type {(state: any, props: {obj?: object, rawEnvData?: any, readOnly: boolean, envPath: any, onChange?: (env: any) => void, addConfigMapSecret?: boolean, useLoadingInline?: boolean}) => {model: K8sKind}} */
+const stateToProps = ({k8s, UI}, {obj}) => ({
+  model: k8s.getIn(['RESOURCES', 'models', referenceFor(obj)]) || k8s.getIn(['RESOURCES', 'models', obj.kind]),
+  impersonate: UI.get('impersonate'),
+});
+
 export const EnvironmentPage = connect(stateToProps)(
   class EnvironmentPage extends PromiseComponent {
   /**
@@ -246,8 +267,7 @@ export const EnvironmentPage = connect(stateToProps)(
       this.saveChanges = this._saveChanges.bind(this);
       this.updateEnvVars = this._updateEnvVars.bind(this);
       this.selectContainer = this._selectContainer.bind(this);
-      const currentEnvVars = new CurrentEnvVars();
-      currentEnvVars.setRawData(this.props.rawEnvData);
+      const currentEnvVars = new CurrentEnvVars(this.props.rawEnvData);
       this.state = {
         currentEnvVars,
         success: null,
@@ -257,8 +277,7 @@ export const EnvironmentPage = connect(stateToProps)(
     }
 
     componentDidMount() {
-      super.componentDidMount();
-
+      this._checkEditAccess();
       const {addConfigMapSecret, readOnly} = this.props;
       if (!addConfigMapSecret || readOnly) {
         const configMaps = {}, secrets = {};
@@ -287,7 +306,51 @@ export const EnvironmentPage = connect(stateToProps)(
           };
         }),
       ])
-        .then(_.spread((configMaps, secrets) => this.setState({configMaps, secrets})));
+        .then((([configMaps, secrets]) => this.setState({configMaps, secrets})));
+    }
+
+    componentDidUpdate(prevProps) {
+      const { obj, model, impersonate, readOnly, rawEnvData } = this.props;
+      const { dirty } = this.state;
+
+      if (!_.isEqual(rawEnvData, prevProps.rawEnvData)) {
+        this.setState({
+          ...!dirty && { currentEnvVars: new CurrentEnvVars(rawEnvData) },
+          stale: dirty,
+        });
+      }
+
+      if (_.get(prevProps.obj, 'metadata.uid') !== _.get(obj, 'metadata.uid') ||
+          _.get(prevProps.model, 'apiGroup') !== _.get(model, 'apiGroup') ||
+          _.get(prevProps.model, 'path') !== _.get(model, 'path') ||
+          prevProps.impersonate !== impersonate ||
+          prevProps.readOnly !== readOnly) {
+        this._checkEditAccess();
+      }
+    }
+
+    _checkEditAccess() {
+      const { obj, model, impersonate, readOnly } = this.props;
+      if (readOnly) {
+        return;
+      }
+
+      // Only check RBAC if editing an existing resource. The form will always
+      // be enabled when creating a new application (git import / deploy image).
+      if (_.isEmpty(obj) || !model) {
+        this.setState({ allowed: true });
+        return;
+      }
+
+      const { name, namespace } = obj.metadata;
+      const resourceAttributes = {
+        group: model.apiGroup,
+        resource: model.plural,
+        verb: 'patch',
+        name,
+        namespace,
+      };
+      checkAccess(resourceAttributes, impersonate).then(resp => this.setState({ allowed: resp.status.allowed }));
     }
 
     /**
@@ -296,18 +359,14 @@ export const EnvironmentPage = connect(stateToProps)(
      * @param i
      */
     _updateEnvVars(env, i = 0, type = EnvType.ENV) {
-      const {rawEnvData, onChange} = this.props;
+      const {onChange} = this.props;
       const {currentEnvVars, containerType} = this.state;
       const currentEnv = _.cloneDeep(currentEnvVars);
-      const originalEnv = new CurrentEnvVars();
-      originalEnv.setRawData(rawEnvData);
       currentEnv.setFormattedVars(containerType, i, type, env.nameValuePairs);
-      const modified = !_.isEqual(currentEnv, originalEnv);
-
       this.setState({
         currentEnvVars: currentEnv,
+        dirty: true,
         success: null,
-        modified,
       });
       _.isFunction(onChange) && onChange(currentEnv.dispatchNewEnvironmentVariables());
     }
@@ -318,41 +377,15 @@ export const EnvironmentPage = connect(stateToProps)(
      */
     _reload() {
       const {rawEnvData} = this.props;
-      this.setState((prevState) => {
-        const {currentEnvVars} = prevState;
-        const reloadedEnvVars = _.cloneDeep(currentEnvVars);
-        reloadedEnvVars.setRawData(rawEnvData);
-        return {
-          errorMessage: null,
-          success: null,
-          modified: false,
-          stale: false,
-          currentEnvVars: reloadedEnvVars,
-        };
+      this.setState({
+        currentEnvVars: new CurrentEnvVars(rawEnvData),
+        dirty: false,
+        errorMessage: null,
+        stale: false,
+        success: null,
       });
     }
 
-    /**
-     * Build out our currentEnvVars state object from our incoming props.
-     * If there is a change and are read/write let the user know we have updated vars otherwise just refresh the page.
-     * For no change return null
-     *
-     * @param nextProps
-     * @param prevState
-     */
-    static getDerivedStateFromProps(nextProps, prevState) {
-      const { currentEnvVars } = prevState;
-      const { rawEnvData, readOnly } = nextProps;
-      const incomingEnvVars = new CurrentEnvVars();
-      incomingEnvVars.setRawData(rawEnvData);
-      if (_.isEqual(currentEnvVars, incomingEnvVars)) {
-        return null;
-      }
-      return readOnly ? {
-        currentEnvVars,
-      } : {stale: true, success: null};
-    }
-
     _selectContainer(containerName) {
       const { rawEnvData } = this.props;
       let containerIndex = _.findIndex(rawEnvData.containers, {name: containerName});
@@ -389,22 +422,24 @@ export const EnvironmentPage = connect(stateToProps)(
       const patches = currentEnvVars.getPatches(envPath);
       const promise = k8sPatch(model, obj, patches);
       this.handlePromise(promise).then((res) => {
-        const newEnvVars = new CurrentEnvVars();
-        newEnvVars.setResultObject(res, currentEnvVars.isContainerArray, envPath);
-
         this.setState({
-          success: 'Successfully updated the environment variables.',
+          currentEnvVars: new CurrentEnvVars(res, currentEnvVars.isContainerArray, envPath),
+          dirty: false,
           errorMessage: null,
-          currentEnvVars: newEnvVars,
-          modified: false,
           stale: false,
+          success: 'Successfully updated the environment variables.',
         });
       });
     }
 
+    dismissSuccess = () => {
+      this.setState({ success: null });
+    }
+
     render() {
-      const {errorMessage, success, inProgress, currentEnvVars, stale, configMaps, secrets, containerIndex, containerType} = this.state;
-      const {rawEnvData, readOnly, obj, addConfigMapSecret, useLoadingInline} = this.props;
+      const {errorMessage, success, inProgress, currentEnvVars, stale, configMaps, secrets, containerIndex, containerType, allowed} = this.state;
+      const {rawEnvData, obj, addConfigMapSecret, useLoadingInline} = this.props;
+      const readOnly = this.props.readOnly || !allowed;
 
       if (!configMaps || !currentEnvVars || !secrets) {
         if (useLoadingInline) {
@@ -421,13 +456,13 @@ export const EnvironmentPage = connect(stateToProps)(
         onChange={this.selectContainer} /> : null;
 
       const owners = _.get(obj.metadata, 'ownerReferences', [])
-        .map((o, i) => <ResourceLink key={i} kind={referenceForOwnerRef(o)} name={o.name} namespace={obj.metadata.namespace} title={o.uid} />);
-      const resourceName = _.get(obj.metadata, 'name', '');
+        .map((o, i) => <ResourceLink key={i} kind={referenceForOwnerRef(o)} name={o.name} namespace={obj.metadata.namespace} title={o.uid} inline />);
       const containerVars =
         <React.Fragment>
           { (readOnly && !_.isEmpty(owners)) &&
             <div className="co-toolbar__group co-toolbar__group--left">
-              <Alert className="col-md-11 col-xs-10" type="info">Environment variables for {resourceName} were set from the resource {owners.length > 1 ? 'owners' : 'owner'}: <span className="environment-resource-link">{owners}</span>
+              <Alert isInline className="co-alert col-md-11 col-xs-10" variant="info" title="Environment variables set from parent">
+                View environment for resource {owners.length > 1 ? <React.Fragment>owners: {owners}</React.Fragment> : owners}
               </Alert>
             </div>
           }
@@ -459,17 +494,14 @@ export const EnvironmentPage = connect(stateToProps)(
       return <div className={classNames({'co-m-pane__body': !currentEnvVars.isCreate})}>
         {containerVars}
         { !currentEnvVars.isCreate && <div className="co-m-pane__body-group">
-          <div className="environment-buttons">
-            {errorMessage && <p className="alert alert-danger"><span className="pficon pficon-error-circle-o" aria-hidden="true"></span>{errorMessage}</p>}
-            {stale && <p className="alert alert-info"><span className="pficon pficon-info" aria-hidden="true"></span>The
-              information on this page is no longer current. Click Reload to update and lose edits, or Save Changes to
-              overwrite.</p>}
-            {success &&
-            <p className="alert alert-success"><span className="pficon pficon-ok" aria-hidden="true"></span>{success}
-            </p>}
-            {!readOnly &&
-            <button disabled={inProgress} type="submit" className="btn btn-primary" onClick={this.saveChanges}>Save</button>}
-            {!readOnly && <button disabled={inProgress} type="button" className="btn btn-default" onClick={this.reload}>Reload</button>}
+          <div className="pf-c-form environment-buttons">
+            {errorMessage && <Alert isInline className="co-alert" variant="danger" title={errorMessage} />}
+            {stale && <Alert isInline className="co-alert" variant="info" title="The information on this page is no longer current.">Click Reload to update and lose edits, or Save Changes to overwrite.</Alert>}
+            {success && <Alert isInline className="co-alert" variant="success" title={success} action={<AlertActionCloseButton onClose={this.dismissSuccess} />} />}
+            {!readOnly && <ActionGroup>
+              <Button isDisabled={inProgress} type="submit" variant="primary" onClick={this.saveChanges}>Save</Button>
+              <Button isDisabled={inProgress} type="button" variant="secondary" onClick={this.reload}>Reload</Button>
+            </ActionGroup>}
           </div>
         </div> }
       </div>;
