@@ -4,7 +4,7 @@ import { connect } from 'react-redux';
 import * as _ from 'lodash-es';
 
 import { OAuthModel } from '../models';
-import { userStateToProps } from '../ui/ui-reducers';
+import { userStateToProps } from '../reducers/ui';
 import { KUBE_ADMIN_USERNAME } from '../const';
 import { resourcePathFromModel } from './utils/resource-link';
 
