@@ -1,9 +1,8 @@
-/* eslint-disable no-undef, no-unused-vars */
-
 import * as React from 'react';
+import { BanIcon } from '@patternfly/react-icons';
 
 export const Phase: React.SFC<PhaseProps> = ({status}) => <span className={status === 'Failed' ? 'co-error' : ''}>
-  { status === 'Failed' && <i className="fa fa-ban" /> } {status}
+  { status === 'Failed' && <BanIcon data-test-id="ban-icon" /> } {status}
 </span>;
 
 export type PhaseProps = {
