@@ -1,9 +1,9 @@
 import React from 'react';
-import ReactDOM from 'react-dom';
 import PropTypes from 'prop-types';
 import { Terminal as XTerminal } from 'xterm';
 import * as fit from 'xterm/lib/addons/fit/fit';
 import * as full from 'xterm/lib/addons/fullscreen/fullscreen';
+import { CompressIcon } from '@patternfly/react-icons';
 
 XTerminal.applyAddon(fit);
 XTerminal.applyAddon(full);
@@ -87,13 +87,14 @@ export class Terminal extends React.Component {
       return;
     }
 
+    const pageRect = document.getElementsByClassName('pf-c-page')[0].getBoundingClientRect();
     const bodyRect = document.body.getBoundingClientRect();
     const nodeRect = node.getBoundingClientRect();
 
     const { padding } = this.props;
 
     // This assumes we want to fill everything below and to the right.  In full-screen, fill entire viewport
-    const height = Math.floor(bodyRect.bottom - (this.isFullscreen ? 0 : nodeRect.top) - padding);
+    const height = Math.floor(pageRect.bottom - (this.isFullscreen ? 0 : nodeRect.top) - padding);
     const width = Math.floor(bodyRect.width - (this.isFullscreen ? 0 : nodeRect.left) - (this.isFullscreen ? 10 : padding));
 
     if (height === this.state.height && width === this.state.width) {
@@ -117,7 +118,7 @@ export class Terminal extends React.Component {
     return <div ref={this.outerRef} style={this.state} className={this.props.className}>
       <div ref={this.innerRef} className="console">
         { this.isFullscreen && <button className="btn btn-link console-collapse-link" onClick={() => this.setFullscreen(false)}>
-          <i className="fa fa-compress" aria-hidden="true" /> Collapse
+          <CompressIcon className="co-icon-space-r" />Collapse
         </button> }
       </div>
     </div>;
